@@ -4,6 +4,7 @@ from watchdog.observers import Observer
 import base64
 import logging
 import os
+import re
 import redis
 import requests
 import signal
@@ -25,6 +26,7 @@ REDIS_PORT = int(os.getenv("REDIS_PORT", 6379))
 REDIS_DB = int(os.getenv("REDIS_DB", 0))
 REDIS_PASSWORD = os.getenv("REDIS_PASSWORD", None)
 REDIS_TTL = int(os.getenv("REDIS_TTL", 60))
+REDIS_SAMPLE_RATE = int(os.getenv("REDIS_SAMPLE_RATE", 8)) # 1/8 images will be post to redis
 redis_hosts = requests.get(REDIS_HOST_LIST_URL).json() if REDIS_HOST_LIST_URL else [REDIS_HOST]
 
 BASE64_ENCODE = "BASE64_ENCODE" in os.environ
@@ -45,27 +47,41 @@ def post(path):
     with open(path, 'rb') as content:
         data = content.read()
         http_data = base64.b64encode(data) if BASE64_ENCODE else data
-        for http_host in [h for h in http_hosts if h]:
-            url = HTTP_PUBLISH_URL_TEMPLATE.format(channel=channel, host=http_host, port=HTTP_PORT)
-            r = requests.post(url, data=http_data)
-            if r.status_code == 200:
-                logger.debug('Pushed {} to {}'.format(path, url))
-            else:
-                logger.error(r)
-        for redis_host in [h for h in redis_hosts if h]:
-            try:
-                r = redis.StrictRedis(host=redis_host, port=REDIS_PORT, db=REDIS_DB, password=REDIS_PASSWORD)
-                key = uuid.uuid4()
-                timestamp = os.path.getmtime(path)
-                r.zadd(channel, timestamp, key)
-                r.setex(key, REDIS_TTL, data)
-                r.zremrangebyscore(channel, "-inf", timestamp - REDIS_TTL)
-                logger.debug('Pushed {} to {}. Key={}, timestamp={}'.format(path, redis_host, key, timestamp))
-            except Exception as err:
-                logger.error(err)
+        post_http(channel, http_data, path)
+        post_redis(channel, data, path)
     os.remove(path)
 
 
+def post_http(channel, data, path):
+    for http_host in [h for h in http_hosts if h]:
+        url = HTTP_PUBLISH_URL_TEMPLATE.format(channel=channel, host=http_host, port=HTTP_PORT)
+        r = requests.post(url, data=data)
+        if r.status_code == 200:
+            logger.debug('Pushed {} to {}'.format(path, url))
+        else:
+            logger.error(r)
+
+
+def post_redis(channel, data, path):
+    digits = re.findall("(\d+)", path)
+    if digits:
+        count = int(digits[-1]) % REDIS_SAMPLE_RATE
+        if count != 0:
+            logger.debug('Image {} not sampled ({}/{}).'.format(path, count, REDIS_SAMPLE_RATE))
+            return
+    for redis_host in [h for h in redis_hosts if h]:
+        try:
+            r = redis.StrictRedis(host=redis_host, port=REDIS_PORT, db=REDIS_DB, password=REDIS_PASSWORD)
+            key = uuid.uuid4()
+            timestamp = os.path.getmtime(path)
+            r.zadd(channel, timestamp, key)
+            r.setex(key, REDIS_TTL, data)
+            r.zremrangebyscore(channel, "-inf", timestamp - REDIS_TTL)
+            logger.debug('Pushed {} to {}. Key={}, timestamp={}'.format(path, redis_host, key, timestamp))
+        except Exception as err:
+            logger.error(err)
+
+
 def setup_logger():
     formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
     handler = None
